<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0">
    <xsl:template match="/">
        <html>
            <head>
                <title>UCV - <xsl:value-of select="/character/name/text()"/></title>
                <style type="text/css">
                    BODY 
                    {
                    font-size:100%;  /* default font size is 16 pixels */
                    font-family:sans-serif;
                    } 
                    p{font-size:0.75em;}
                    td{font-size:0.75em;}
                </style>
            </head>
            <body>
                <h2><xsl:value-of select="/character/name/text()"/></h2>
                <!-- Include Journals, if available. -->
                <xsl:for-each select="//article">
                        <article>
                            <xsl:attribute name="title"><xsl:value-of select="@title"/></xsl:attribute>
                            <h4><xsl:value-of select="@title"/></h4>
                            <xsl:for-each select="span">
                                <span>
                                    <xsl:attribute name="style"><xsl:value-of select="@style"/></xsl:attribute>
                                    <xsl:value-of select="text()"/>
                                    <xsl:if test="br">
                                        <br />
                                    </xsl:if>
                                </span>
                            </xsl:for-each>
                        </article>
                    <br />
                </xsl:for-each>
                <p>
                    <strong>Attributes: </strong>
                    <xsl:for-each select="/character/datablock[@name='Attributes']/data">
                        <xsl:value-of select="@name"/>(<xsl:value-of select="text()"/>)   
                    </xsl:for-each>
                    <br />
                    <strong>Skills: </strong>
                    <xsl:for-each select="/character/datablock[@name='Mental Abilities']/data">
                        <xsl:if test="text() != ''">
                            <xsl:value-of select="@name"/>(<xsl:value-of select="text()"/>)
                        </xsl:if>
                    </xsl:for-each>
                    <xsl:for-each select="/character/datablock[@name='Physical Abilities']/data">
                        <xsl:if test="text() != ''">
                            <xsl:value-of select="@name"/>(<xsl:value-of select="text()"/>) 
                        </xsl:if>
                    </xsl:for-each>
                    <xsl:for-each select="/character/datablock[@name='Social Abilities']/data">
                        <xsl:if test="text() != ''">
                            <xsl:value-of select="@name"/>(<xsl:value-of select="text()"/>) 
                        </xsl:if>
                    </xsl:for-each>
                    <br />
                    <strong>Merits: </strong>
                    <xsl:for-each select="/character/datablock[@name='Merits']/data">
                            <xsl:choose>
                                <xsl:when test="@renamed != ''">
                                    <xsl:value-of select="@renamed"/> 
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="@name"/> 
                                </xsl:otherwise>
                            </xsl:choose>
                            (<xsl:value-of select="text()"/>)  
                    </xsl:for-each>
                    <br />
                    <table border="0">
                        <tr>
                            <td><strong>Health: </strong></td>
                            <td><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Health']/text()"/></td>
                        </tr>
                        <xsl:if test="/character/datablock[@name='Secondary Attributes']/data[@name='Damage Taken']/text() !=''">
                            <tr>
                                <td>Damage: </td>
                                <td><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Damage Taken']/text()"/></td>
                            </tr>
                        </xsl:if>
                    </table>
                    <table border="0">
                    <tr>
                        <td><strong>Willpower </strong></td>
                        <td><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Willpower']"/></td>
                    </tr>
                    <xsl:if test="/character/datablock[@name='Secondary Attributes']/data[@name='WP Spent']/text() !=''">
                        <tr>
                            <td>Spent: </td>
                            <td><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='WP Spent']/text()"/></td>
                        </tr>
                    </xsl:if>
                    </table>
                    <strong>Morality </strong><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Morality']"/> 
                    <xsl:if test="/character/datablock[@name='Secondary Attributes']/data[@name='Derangements'] != ''">
                        <strong>Derangements: </strong><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Derangements']/text()"/>
                    </xsl:if>
                    <br />
                    <strong>Virtue: </strong><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Virtue']/text()"/><br />
                    <strong>Vice: </strong><xsl:value-of select="/character/datablock[@name='Description']/data[@name='Vice']/text()"/><br />
                    <strong>Initiative: </strong><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Initiative']/text()"/><br />
                    <strong>Defense: </strong><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Defense']/text()"/><br />
                    <xsl:if test="/character/datablock[@name='Secondary Attributes']/data[@name='Armor']/text() !=''">
                        <strong>Armor: </strong><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Armor']/text()"/><br />
                    </xsl:if>
                    <strong>Speed: </strong><xsl:value-of select="/character/datablock[@name='Secondary Attributes']/data[@name='Speed']/text()"/><br />
                </p>
                <table>
                    <tr>
                        <th colspan="2" align="left">Equipment</th>
                    </tr>
                    <xsl:for-each select="/character/datablock[@name='Equipment']/data">
                        <xsl:if test="@renamed != ''">
                            <xsl:if test="@renamed != 'Equipment'">
                                <tr>
                                    <td valign="top"><xsl:value-of select="@renamed"/></td>
                                    <td valign="top"><em><xsl:value-of select="text()"/></em></td>
                                </tr>
                            </xsl:if>
                        </xsl:if>
                    </xsl:for-each>
                </table>
            </body>
        </html>
    </xsl:template>
</xsl:stylesheet>